from setuptools import setup

setup(
    name='luaprot',
    version='1.0.2',
    packages=['luaprot'],
    author='luaprot',
    author_email='protlua@gmail.com',
    description='The offical python package for the LuaProt whitelisting service',
)